# -*- coding: utf-8 -*-


from odoo import models, api
from odoo.tools.translate import _
from odoo.exceptions import AccessError
from odoo.http import request
from odoo.addons.saas_worker.util import version_gte, SupportLevel as SL

# Profiling was introduced in saas-14.4, which was never released
if version_gte('15.0'):
    class IrProfile(models.Model):
        _inherit = 'ir.profile'
        _description = 'Allow profiling only to Tech Support level'


        @api.model
        def set_profiling(self, profile=None, collectors=None, params=None):
            """
            Enable or disable profiling for the current user, if done by the Support Team
            """
            impostor_info = request and request.session.impostor_info
            if impostor_info and impostor_info.get('support_level', SL.CUSTOMER) >= SL.FUNCTIONAL_SUPPORT:
                return super(IrProfile, self).set_profiling(profile=profile, collectors=collectors, params=params)
            else:
                raise AccessError(_("Profiling features can only be used by the Support Team of Odoo. \nYou can contact our support at https://www.odoo.com/help"))
